def celsius_para_fahrenheit(temp_em_celsius):
    temp_em_fahrenheit = 1.8 * temp_em_celsius + 32
    return temp_em_fahrenheit

def fahrenheit_para_celsius(temp_em_fahrenheit):
    temp_em_celsius = (temp_em_fahrenheit - 32) / 1.8
    return temp_em_celsius



from setuptools import setup

setup(
    name = 'temperatura',
    version = '2.0.0',
    author = 'Lissandro',
    packages = ['temperatura'],
    description = 'Um simples conversor de temperatura (Celsius - Fahrenheit)',
    long_description = 'Um simples conversor de temperatura, com funções para '
                        + 'conversão de Celsius para Fahrenheit e vice-versa, '
                        + 'usado para um aprendizado na criação de pacotes',
    url="https://github.com/lissandro1/li-simple-package-template",
    license = 'MIT'
)